@@ -1,7 +1,7 @@
 /*
  * Plumbing.java
  *
- * Copyright (c) 2006-2007 Operational Dynamics Consulting Pty Ltd, and Others
+ * Copyright (c) 2006-2008 Operational Dynamics Consulting Pty Ltd, and Others
  * 
  * The code in this file, and the library it is a part of, are made available
  * to you by the authors under the terms of the "GNU General Public Licence,
@@ -35,30 +35,24 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
 
     protected Plumbing() {}
 
-    private static final IdentityHashMap typeMapping;
+    private static final IdentityHashMap<String, String> typeMapping;
 
     private static final String TYPE_MAPPING = "typeMapping.properties";
 
     static {
+        final InputStream is;
+        final Properties p;
+
         Glib.checkInitialized();
 
         lock = Gdk.lock;
 
-        typeMapping = new IdentityHashMap(100);
+        typeMapping = new IdentityHashMap<String, String>(470);
 
-        // FUTURE do we still need this?
-        registerType("gchararray", Primitive.class);
-        registerType("gboolean", Primitive.class);
-        registerType("gint", Primitive.class);
-        registerType("guint", Primitive.class);
-        registerType("gint32", Primitive.class);
-        registerType("guint32", Primitive.class);
-
-        Properties p = new Properties();
+        p = new Properties();
 
         try {
-            ClassLoader cl = Plumbing.class.getClassLoader();
-            InputStream is = cl.getResourceAsStream(TYPE_MAPPING);
+            is = loader.getResourceAsStream(TYPE_MAPPING);
             if (is == null) {
                 throw new NullPointerException("InputStream for " + TYPE_MAPPING + " is null");
             }
@@ -71,7 +65,7 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
             System.exit(2);
         }
 
-        for (Iterator iter = p.keySet().iterator(); iter.hasNext();) {
+        for (Iterator<java.lang.Object> iter = p.keySet().iterator(); iter.hasNext();) {
             String gType = (String) iter.next();
             String javaClass = (String) p.get(gType);
             registerType(gType, javaClass);
@@ -86,24 +80,11 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * be) written.
      */
     protected static void registerType(String nativeName, String javaClassName) {
-        final Class javaClass;
 
-        assert (javaClassName != null) : "Java class being registered cannot be null";
+        assert ((nativeName != null) && (!nativeName.equals(""))) : "GType name being registered cannot be null or empty";
+        assert (javaClassName != null) : "Java class name being registered cannot be null";
 
-        try {
-            javaClass = Class.forName(javaClassName);
-        } catch (ClassNotFoundException e) {
-            /*
-             * By design we ignore this and return. There is a logic hole
-             * here, though - if someone mistypes a class that does exist,
-             * then it won't be registered. The bug will be exposed by an
-             * UnsupportedOperationException being thrown by objectFor() when
-             * it can't look up what it rightly should be able to.
-             */
-            return;
-        }
-
-        registerType(nativeName, javaClass);
+        typeMapping.put(nativeName.intern(), javaClassName.intern());
     }
 
     /**
@@ -112,12 +93,9 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * all, you should also have implemented the public class that goes along
      * with it!
      */
-    protected static void registerType(String nativeName, Class javaClass) {
-
-        assert ((nativeName != null) && (!nativeName.equals(""))) : "GType name being registered cannot be null or empty";
+    protected static void registerType(String nativeName, Class<?> javaClass) {
         assert (javaClass != null) : "Java class being registered cannot be null";
-
-        typeMapping.put(nativeName.intern(), javaClass);
+        registerType(nativeName, javaClass.getName());
     }
 
     /**
@@ -139,7 +117,7 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * Retrieve an array of appropriate Java Boxeds for the given array of
      * pointers.
      */
-    protected static Boxed[] boxedArrayFor(final Class type, final long[] pointers, Boxed[] boxeds) {
+    protected static Boxed[] boxedArrayFor(final Class<?> type, final long[] pointers, Boxed[] boxeds) {
         if (pointers == null) {
             return null;
         }
@@ -156,7 +134,7 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * @throw ClassCastException if the GType pointed by given pointer is not
      *        a GBoxed.
      */
-    protected static Boxed boxedFor(Class type, final long pointer) {
+    protected static Boxed boxedFor(Class<?> type, final long pointer) {
         Proxy proxy;
 
         if (pointer == 0L) {
@@ -197,7 +175,7 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * 
      * @see #boxedFor(Class, long)
      */
-    protected static void fillBoxedArray(Class type, Boxed[] boxeds, long[] pointers) {
+    protected static void fillBoxedArray(Class<?> type, Boxed[] boxeds, long[] pointers) {
         if (pointers == null) {
             return;
         }
@@ -243,17 +221,17 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
              * exception.
              */
             final String name;
-            final Class type;
+            final Class<?> type;
 
             /*
              * We intern the returned GType name string to reduce memory
              * pressure and to permit lookup by identity.
              */
 
-            name = GObject.typeName(pointer).intern();
+            name = GObject.typeName(pointer);
 
             if (name.equals("")) {
-                throw new IllegalStateException("\nGType name lookup failed");
+                throw new IllegalStateException("\n" + "GType name lookup failed");
             }
 
             /*
@@ -261,21 +239,10 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
              * instance for the Proxy subclass.
              */
 
-            type = (Class) typeMapping.get(name);
+            type = lookupType(name);
 
-            if (type != null) {
-                proxy = createProxy(type, pointer);
-                return (Object) proxy;
-            }
-
-            /*
-             * But failing that, the constructor being null indicates that we
-             * don't have any information about this native type and how to
-             * map it to Java. So,
-             */
-
-            throw new UnsupportedOperationException("\nNo binding for " + name
-                    + " (yet!), GObject code path");
+            proxy = createProxy(type, pointer);
+            return (Object) proxy;
         }
     }
 
@@ -316,8 +283,23 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
     /**
      * Get the Class object that this supplied name maps to.
      */
-    protected final static Class lookupType(String name) {
-        return (Class) typeMapping.get(name);
+    protected final static Class<?> lookupType(String name) {
+        final String java;
+
+        java = typeMapping.get(name);
+
+        if (java == null) {
+            /*
+             * No class indicates that we don't have any information about
+             * this native type and how to map it to Java. So,
+             */
+            throw new FatalError("\n" + "No mapping for " + name + " (yet!)");
+        }
+        try {
+            return Class.forName(java, true, loader);
+        } catch (ClassNotFoundException cnfe) {
+            throw new FatalError("\n" + "Mapping exists, but class not found! " + cnfe.getMessage());
+        }
     }
 
     /**
@@ -342,9 +324,19 @@ public abstract class Plumbing extends org.freedesktop.bindings.Plumbing
      * In this case we need to go back to GObject in order to be able to make
      * the native call to our g_signal_connect() wrapper.
      */
-    protected static final void connectSignal(Object instance, Signal handler, Class receiver,
+    protected static final void connectSignal(Object instance, Signal handler, Class<?> receiver,
             String name) {
         GObject.g_signal_connect(pointerOf(instance), handler, receiver, name);
         instance.addHandler(handler);
     }
+
+    /*
+     * FIXME this is a pathetic hack, only here to permit compilation to
+     * succeed while we work out a better means of handling the cross-package
+     * visibility issue. Entities are the various Cairo types.
+     */
+    protected static Proxy entityFor(Class<?> type, long pointer) {
+        throw new UnsupportedOperationException(
+                "Unfortunately, we haven't figured out how to call the method in Cairo's Plumbing yet");
+    }
 }
